/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/

#include "host/loglevel.h"

#include <algorithm>
#include <map>

#include "boost_assert_handler.h"

using namespace std;
using I2n::Logger::LogLevel;

//-----------------------------------------------------------------------------
// LogLevel
//-----------------------------------------------------------------------------

static map<string, LogLevel> log_level_string_map;

LogLevel get_log_level_from_string( const string & log_level_string )
{
    BOOST_ASSERT( !log_level_string.empty() );

    // convert to uppercase to allow the log_level to be case insensitive
    string log_level_uppercase_string( log_level_string );
    transform( log_level_string.begin(), log_level_string.end(),
               log_level_uppercase_string.begin(),
               ::toupper );                                                                           //lint !e534

    // TODO move to an init method
    log_level_string_map[ "DEBUG" ] = LogLevel::Debug;
    log_level_string_map[ "INFO" ] = LogLevel::Info;
    log_level_string_map[ "NOTICE" ] = LogLevel::Notice;
    log_level_string_map[ "WARNING" ] = LogLevel::Warning;
    log_level_string_map[ "ERROR" ] = LogLevel::Error;
    log_level_string_map[ "CRITICAL" ] = LogLevel::Critical;
    log_level_string_map[ "ALERT" ] = LogLevel::Alert;
    log_level_string_map[ "EMERGENCY" ] = LogLevel::Emergency;

    LogLevel log_level = log_level_string_map[ log_level_uppercase_string ];

    return log_level;
}
